#*******************************************************************************
#**  This file is part of Qt Mocks.                                          ***
#**                                                                          ***
#**  Copyright (C) 2018, 2019, 2020, 2021                                    ***
#**  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Lesser General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Lesser General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Lesser General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************
from conans import ConanFile, CMake, tools


class QtMocksConan(ConanFile):
	name = "qt-mocks"
	version = "0.4.0"
	license = "LGPLv3"
	author = "John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>"
	url = "https://source.schneiderman.me/qt-mocks/"
	description = "Mocking Qt library using Qt Test inspired by Google Test."
	#topics = ("<Put some tag here>", "<here>", "<and here>")
	settings = "os", "compiler", "build_type", "arch"
	options = {
		"shared": [True, False]
	}
	default_options = {
		"shared": False
	}
	generators = "cmake"
	requires = "qt/5.11.3@bincrafters/stable"


	def source(self):
		self.run("hg clone {url} -r {version_tag}".format(url=QtMocksConan.url, version_tag=QtMocksConan.version))

	def build(self):
		cmake = CMake(self)
		cmake.configure(source_folder="qt-mocks")
		cmake.definitions['Qt-Mocks_BUILD_SHARED_LIBRARY'] = 'ON' if self.options.shared else 'OFF'
		cmake.build()

	def package(self):
		cmake = CMake(self)
		cmake.install()

	def package_info(self):
		self.cpp_info.includedirs = ["include/qt-mocks"]
		self.cpp_info.libs = ["qt-mocks"]
